@@ -1,66 +1,48 @@
 package RDF::RDFa::Parser::Config;
 
-BEGIN {
-	$RDF::RDFa::Parser::Config::AUTHORITY = 'cpan:TOBYINK';
-	$RDF::RDFa::Parser::Config::VERSION   = '1.096_04';	
-}
-
-use parent qw(Exporter);
+use base qw(Exporter);
 use constant {
-	HOST_ATOM     => 'atom',
-	HOST_DATARSS  => 'datarss',
-	HOST_HTML32   => 'html32',
-	HOST_HTML4    => 'html4',
-	HOST_HTML5    => 'html5',
+	HOST_ATOM  => 'atom',
+	HOST_DATARSS => 'datarss',
+	HOST_HTML4 => 'html4',
+	HOST_HTML5 => 'html5',
 	HOST_OPENDOCUMENT_XML => 'opendocument-xml',
 	HOST_OPENDOCUMENT_ZIP => 'opendocument-zip',
-	HOST_SVG      => 'svg',
-	HOST_XHTML    => 'xhtml',
-	HOST_XHTML5   => 'xhtml5',
-	HOST_XML      => 'xml',
+	HOST_SVG   => 'svg',
+	HOST_XHTML => 'xhtml',
+	HOST_XML   => 'xml',
 };
 use constant {
 	RDFA_10     => '1.0',
 	RDFA_11     => '1.1',
 	RDFA_LATEST => '1.1',
-	RDFA_GUESS  => 'guess',
+	RDFA_GUESS  => '1.1',
 };
-use common::sense;
-use 5.010;
+use strict;
+use 5.008;
 
-use RDF::RDFa::Parser::OpenDocumentObjectModel;
 use URI::Escape qw'uri_unescape';
+use RDF::RDFa::Parser::OpenDocumentObjectModel;
 
-our @EXPORT_OK = qw(HOST_ATOM HOST_DATARSS HOST_HTML4 HOST_HTML5 HOST_OPENDOCUMENT_XML HOST_OPENDOCUMENT_ZIP HOST_SVG HOST_XHTML HOST_XHTML5 HOST_XML RDFA_10 RDFA_11);
-
+our @EXPORT_OK = qw(HOST_ATOM HOST_DATARSS HOST_HTML4 HOST_HTML5 HOST_OPENDOCUMENT_XML HOST_OPENDOCUMENT_ZIP HOST_SVG HOST_XHTML HOST_XML RDFA_10 RDFA_11);
+our $VERSION = '1.091';
 our $CONFIGS = {
 	'host' => {
 		HOST_ATOM() => {
 			'atom_elements'         => 1,
-			'initial_context'       => '',
-			'vocab_default'         => 'http://www.iana.org/assignments/relation/',
+			'keyword_bundles'       => 'rdfa iana',
 		},
 		HOST_DATARSS() => {
 			'atom_elements'         => 1,
-			'initial_context'       => 'http://search.yahoo.com/searchmonkey-profile',
-			'vocab_default'         => 'http://www.iana.org/assignments/relation/',
-		},
-		HOST_HTML32() => {
-			'dom_parser'            => 'html',
-			'embedded_rdfxml'       => 0,
-			'intial_context'        => 'tag:buzzword.org.uk,2010:rdfa:profile:html32',
-			'prefix_nocase_xmlns'   => 1,
-			'xhtml_base'            => 1,
-			'xhtml_elements'        => 1,
-			'xhtml_lang'            => 1,
-			'xml_base'              => 0,
-			'xml_lang'              => 0,
+			'keyword_bundles'       => 'rdfa iana',
+			'default_profiles'      => 'http://search.yahoo.com/searchmonkey-profile',
+			'profile_pi'            => 1,
 		},
 		HOST_HTML4() => {
 			'dom_parser'            => 'html',
 			'embedded_rdfxml'       => 0,
-			'initial_context'       => 'tag:buzzword.org.uk,2010:rdfa:profile:html4 http://www.w3.org/2011/rdfa-context/html-rdfa-1.1',
 			'prefix_nocase_xmlns'   => 1,
+			'keyword_bundles'       => 'rdfa html4',
 			'xhtml_base'            => 1,
 			'xhtml_elements'        => 1,
 			'xhtml_lang'            => 1,
@@ -70,8 +52,8 @@ our $CONFIGS = {
 		HOST_HTML5() => {
 			'dom_parser'            => 'html',
 			'embedded_rdfxml'       => 0,
-			'initial_context'       => 'tag:buzzword.org.uk,2010:rdfa:profile:html5 http://www.w3.org/2011/rdfa-context/html-rdfa-1.1',
 			'prefix_nocase_xmlns'   => 1,
+			'keyword_bundles'       => 'rdfa html5',
 			'xhtml_base'            => 1,
 			'xhtml_elements'        => 1,
 			'xhtml_lang'            => 1,
@@ -97,16 +79,11 @@ our $CONFIGS = {
 		HOST_SVG() => {},
 		HOST_XHTML() => {
 			'embedded_rdfxml'       => 0,
+			'keyword_bundles'       => 'rdfa',
 			'xhtml_base'            => 1,
 			'xhtml_elements'        => 1,
 			'xml_base'              => 0,
 		},
-		HOST_XHTML5() => {
-			'embedded_rdfxml'       => 0,
-			'xhtml_base'            => 1,
-			'xhtml_elements'        => 1,
-			'xml_base'              => 2,
-		},
 		HOST_XML() => {},
 	},
 	'rdfa' => {
@@ -118,48 +95,38 @@ our $CONFIGS = {
 			'bookmark_end'          => undef,
 			'bookmark_name'         => undef,
 			'bookmark_start'        => undef,
-			'cite_attr'             => 0,
-			'datetime_attr'         => 0,
+			'default_profiles'      => undef,
 			'dom_parser'            => 'xml',
 			'embedded_rdfxml'       => 1,
 			'full_uris'             => 0,
+			'keyword_bundles'       => 'rdfa',
 			'graph'                 => 0,
 			'graph_attr'            => 'graph',
-			'graph_type'            => 'about',
-			'graph_default'         => undef,
+			'graph_type'            => 'id',
+			'graph_default'         => '_:RDFaDefaultGraph',
 			'graph_default_trine'   => undef,  # not officially exposed
-			'initial_context'       => 'tag:buzzword.org.uk,2010:rdfa:profile:rdfa-1.0',
-			'inlist_attr'           => 0,
-			'longdesc_attr'         => 0,
 			'lwp_ua'                => undef,
 			'ns'                    => undef,
 			'prefix_attr'           => 0,
 			'prefix_bare'           => 0,
-			'prefix_default'        => 'http://www.w3.org/1999/xhtml/vocab#',
+			'prefix_default'        => 0,
+			'prefix_empty'          => 'http://www.w3.org/1999/xhtml/vocab#',
 			'prefix_nocase_attr'    => 0,
 			'prefix_nocase_xmlns'   => 0,
-			'property_resources'    => 0,
+			'profiles'              => 0,
+			'profile_pi'            => 0,
 			'role_attr'             => 0,
 			'safe_anywhere'         => 0,
-			'safe_optional'         => 0,
-			'skolemize'             => 0,
-			'src_sets_object'       => 0,
 			'tdb_service'           => 0,
-			'typeof_resources'      => 0,
-			'uri_class'             => 'URI',
 			'use_rtnlx'             => 0,
 			'user_agent'            => undef,
-			'value_attr'            => 0,
 			'vocab_attr'            => 0,
-			'vocab_default'         => undef,
-			'vocab_triple'          => 0,
 			'xhtml_base'            => 0,
 			'xhtml_elements'        => 0,
 			'xhtml_lang'            => 0,
 			'xml_base'              => 2,
 			'xml_lang'              => 1,
 			'xmllit_default'        => 1,
-			'xmllit_recurse'        => 0,
 			'xmlns_attr'            => 1,
 		},
 		RDFA_11() => {
@@ -170,84 +137,41 @@ our $CONFIGS = {
 			'bookmark_end'          => undef,
 			'bookmark_name'         => undef,
 			'bookmark_start'        => undef,
-			'cite_attr'             => 0,
-			'datetime_attr'         => 0,
+			'default_profiles'      => undef,
 			'dom_parser'            => 'xml',
 			'embedded_rdfxml'       => 1,
 			'full_uris'             => 1, #diff
+			'keyword_bundles'       => '', #diff
 			'graph'                 => 0,
 			'graph_attr'            => 'graph',
-			'graph_type'            => 'about',
-			'graph_default'         => undef,
+			'graph_type'            => 'id',
+			'graph_default'         => '_:RDFaDefaultGraph',
 			'graph_default_trine'   => undef,
-			'inlist_attr'           => 1, #diff
-			'initial_context'       => 'http://www.w3.org/2011/rdfa-context/rdfa-1.1',
-			'longdesc_attr'         => 0,
 			'lwp_ua'                => undef,
 			'ns'                    => undef,
 			'prefix_attr'           => 1, #diff
 			'prefix_bare'           => 0,
-			'prefix_default'        => 'http://www.w3.org/1999/xhtml/vocab#',
+			'prefix_default'        => 0,
+			'prefix_empty'          => 'http://www.w3.org/1999/xhtml/vocab#',
 			'prefix_nocase_attr'    => 1, #diff
 			'prefix_nocase_xmlns'   => 1, #diff
-			'property_resources'    => 1, #diff
+			'profiles'              => 1, #diff
+			'profile_pi'            => 0,
 			'role_attr'             => 0,
 			'safe_anywhere'         => 1, #diff
-			'safe_optional'         => 1, #diff
-			'src_sets_object'       => 1, #diff
-			'skolemize'             => 0,
 			'tdb_service'           => 0,
-			'typeof_resources'      => 1, #diff
-			'uri_class'             => 'URI',
 			'use_rtnlx'             => 0,
 			'user_agent'            => undef,
-			'value_attr'            => 0,
 			'vocab_attr'            => 1, #diff
-			'vocab_default'         => undef,
-			'vocab_triple'          => 1,
 			'xhtml_base'            => 0,
 			'xhtml_elements'        => 0,
 			'xhtml_lang'            => 0,
 			'xml_base'              => 2,
 			'xml_lang'              => 1,
-			'xmllit_default'        => 0, #diff
-			'xmllit_recurse'        => 1, #diff
+			'xmllit_default'        => 0,
 			'xmlns_attr'            => 1,
 		},
 	},
-	'combination' => {
-		'xhtml+1.1' => {
-			'initial_context'       => 'http://www.w3.org/2011/rdfa-context/xhtml-rdfa-1.1 http://www.w3.org/2011/rdfa-context/rdfa-1.1',
-			'xhtml_elements'        => 2,
-			
-			# XHTML+RDFa 1.1 wants to use @lang, though
-			# neither XHTML's host language rules, nor
-			# RDFa 1.1's rules individually use it.
-			'xhtml_lang'            => 1,
-		},
-		'html32+1.1' => {
-			'datetime_attr'         => 1,
-			'value_attr'            => 1,
-			'xhtml_elements'        => 2,
-		},
-		'html4+1.1' => {
-			'datetime_attr'         => 1,
-			'value_attr'            => 1,
-			'xhtml_elements'        => 2,
-		},
-		'html5+1.1' => {
-			'datetime_attr'         => 1,
-			'value_attr'            => 1,
-			'xhtml_elements'        => 2,
-		},
-		'xhtml5+1.1' => {
-			'datetime_attr'         => 1,
-			'initial_context'       => 'tag:buzzword.org.uk,2010:rdfa:profile:html5 http://www.w3.org/2011/rdfa-context/html-rdfa-1.1 http://www.w3.org/2011/rdfa-context/xhtml-rdfa-1.1',
-			'value_attr'            => 1,
-			'xhtml_elements'        => 2,
-			'xhtml_lang'            => 1,
-		},
-	},
 };
 
 sub new
@@ -256,34 +180,29 @@ sub new
 	$host    ||= HOST_XHTML;
 	$version ||= RDFA_11;
 	
-	if ($version eq RDFA_GUESS)
-	{
-		$version = RDFA_11;
-		$options{'guess_rdfa_version'} = 1;
-	}
-	
 	$host = $class->host_from_media_type($host) if $host =~ m'/';
 	
 	my $self = bless {}, $class;
 	
-	if (defined $CONFIGS->{'rdfa'}->{$version})
-	{
-		$self->merge_options($CONFIGS->{'rdfa'}->{$version});
-	}
-	else
-	{
-		die "Unsupported RDFa version: $version";
-	}
+	$self->_merge_options($CONFIGS->{'rdfa'}->{$version})
+		if defined $CONFIGS->{'rdfa'}->{$version};
 	
-	$self->merge_options($CONFIGS->{'host'}->{$host})
+	$self->_merge_options($CONFIGS->{'host'}->{$host})
 		if defined $CONFIGS->{'host'}->{$host};
 
-	$self->merge_options($CONFIGS->{'combination'}->{$host . '+' . $version})
-		if defined $CONFIGS->{'combination'}->{$host . '+' . $version};
-
-	$self->merge_options(\%options)
+	# XHTML+RDFa 1.1 wants to use @lang, though
+	# neither XHTML's host language rules, nor
+	# RDFa 1.1's rules individually use it.
+	if ($host eq HOST_XHTML && $version eq RDFA_11)
+	{
+		$self->{xhtml_lang} = 1;
+	}
+	
+	$self->_merge_options(\%options)
 		if %options;
 	
+	$self->_expand_keywords;
+	
 	$self->{'_host'} = $host;
 	$self->{'_rdfa'} = $version;
 	$self->{'_opts'} = \%options;
@@ -291,18 +210,6 @@ sub new
 	return $self;
 }
 
-sub tagsoup
-{
-	my ($class) = @_;
-	return $class->new(
-		HOST_HTML5,
-		RDFA_LATEST,
-		cite_attr        => 1,
-		role_attr        => 1,
-		longdesc_attr    => 1,
-	);
-}
-
 sub host_from_media_type
 {
 	my ($class, $mediatype) = @_;
@@ -339,40 +246,13 @@ sub rehost
 	return $class->new($host, $version, %$opts);
 }
 
-sub guess_rdfa_version
-{
-	my ($config, $parser) = @_;
-	
-	my $rdfans = $config->{'ns'} || undef;
-	my $version;
-	if ($rdfans)
-	{
-		$version = $parser->dom->documentElement->hasAttributeNS($rdfans, 'version')
-			? $parser->dom->documentElement->getAttributeNS($rdfans, 'version')
-			: undef;
-	}
-	else
-	{
-		$version = $parser->dom->documentElement->hasAttribute('version')
-			? $parser->dom->documentElement->getAttribute('version')
-			: undef;
-	}
-		
-	if (defined $version and $version =~ /\bRDFa\s+(\d+\.\d+)\b/i)
-	{
-		return $config->rehost($config->{'_host'}, $1);
-	}
-	
-	return $config;
-}
-
 sub lwp_ua
 {
 	my ($self) = @_;
 	
 	unless (ref $self->{lwp_ua})
 	{
-		my $uastr = sprintf('%s/%s ', 'RDF::RDFa::Parser', RDF::RDFa::Parser->VERSION);
+		my $uastr = sprintf('%s/%s ', 'RDF::RDFa::Parser', $VERSION);
 		if (defined $self->{'user_agent'})
 		{
 			if ($self->{'user_agent'} =~ /\s+$/)
@@ -402,6 +282,13 @@ sub lwp_ua
 	return $self->{lwp_ua};
 }
 
+sub merge_options
+{
+	my ($self, %opts) = @_;
+	$self->_merge_options(\%opts);
+	$self->_expand_keywords;
+}
+
 sub auto_config
 {
 	my ($self, $parser) = @_;
@@ -428,7 +315,11 @@ sub auto_config
 		next if $o=~ /^(use_rtnlx|dom_parser|auto_config)$/i;
 		$count++;
 		
-		if (lc $o eq 'initial_context')
+		if (lc $o eq 'keywords')
+		{
+			$x->{keyword_bundles} .= ' ' . $options->{$o};
+		}
+		elsif (lc $o eq 'keyword_bundles' || lc $o eq 'default_profiles')
 		{
 			$x->{lc $o} .= ' ' . $options->{$o};
 		}
@@ -459,14 +350,13 @@ sub _parse_application_x_www_form_urlencoded
 	return $rv;
 }
 
-sub merge_options
+sub _merge_options
 {
-	my $self = shift;
-	my %opts = (ref $_[0]) ? %{$_[0]} : @_;
+	my ($self, $opts) = @_;
 	
-	while (my ($key, $value) = each %opts)
+	while (my ($key, $value) = each %$opts)
 	{
-		if ($key =~ m'^(initial_context)$'i
+		if ($key =~ m'^(keyword_bundles|default_profiles)$'i
 		&&  defined $self->{$key}
 		&&  length $self->{$key})
 		{
@@ -484,6 +374,167 @@ sub merge_options
 	}
 }
 
+sub _expand_keywords
+{
+	my $self  = shift;
+	my $terms = $self->{'keyword_bundles'} || '';
+	
+	my $KW = {
+		'about'     => {},
+		'resource'  => {},
+		'rel'       => {},
+		'rev'       => {},
+		'role'      => {},
+		'property'  => {},
+		'datatype'  => {},
+		'typeof'    => {},
+		'graph'     => {},
+		'*'         => {},
+		};
+	my $KW2 = {
+		'about'     => {},
+		'resource'  => {},
+		'rel'       => {},
+		'rev'       => {},
+		'role'      => {},
+		'property'  => {},
+		'datatype'  => {},
+		'typeof'    => {},
+		'graph'     => {},
+		'*'         => {},
+		};
+
+	if ($terms =~ /\b(rdfa|xhv)\b/i)
+	{
+		foreach my $attr (qw(rel rev))
+		{
+			foreach my $word (qw(alternate appendix bookmark cite
+				chapter contents copyright first glossary help icon
+				index last license meta next p3pv1 prev role section
+				stylesheet subsection start top up))
+			{
+				$KW->{ $attr }->{ lc $word } = 'http://www.w3.org/1999/xhtml/vocab#' . (lc $word)
+					unless defined $KW->{ $attr }->{ lc $word };
+			}
+		}
+	}
+
+	if ($terms =~ /\b(html5)\b/i)
+	{
+		foreach my $attr (qw(rel rev))
+		{
+			foreach my $word (qw(alternate archives author bookmark
+				external feed first help icon index last license next
+				nofollow noreferrer pingback prefetch prev search
+				stylesheet sidebar tag up ALTERNATE-STYLESHEET))
+			{
+				$KW->{ $attr }->{ lc $word } = 'http://www.w3.org/1999/xhtml/vocab#' . $word
+					unless defined $KW->{ $attr }->{ lc $word };
+			}
+		}
+	}
+	
+	if ($terms =~ /\b(html4)\b/i)
+	{
+		foreach my $attr (qw(rel rev))
+		{
+			foreach my $word (qw(Alternate Stylesheet Start Next
+				Prev Contents Index Glossary Copyright Chapter
+				Section Subsection Appendix Help Bookmark))
+			{
+				$KW->{ $attr }->{ lc $word } = 'http://www.w3.org/1999/xhtml/vocab#' . (lc $word)
+					unless defined $KW->{ $attr }->{ lc $word };
+			}
+		}
+	}
+	
+	if ($terms =~ /\b(html32)\b/i)
+	{
+		foreach my $attr (qw(rel rev))
+		{
+			foreach my $word (qw(top contents index glossary copyright
+				next previous help search chapter made))
+			{
+				$KW->{ $attr }->{ lc $word } = 'http://www.w3.org/1999/xhtml/vocab#' . $word
+					unless defined $KW->{ $attr }->{ lc $word };
+			}
+		}
+	}
+	
+	if ($terms =~ /\b(iana)\b/i)
+	{
+		foreach my $attr (qw(rel rev))
+		{
+			foreach my $word (qw(alternate appendix bookmark chapter
+				contents copyright current describedby edit edit-media
+				enclosure first glossary help hub index last latest-version
+				license next next-archive payment predecessor-version
+				prev previous prev-archive related replies section self
+				service start stylesheet subsection successor-version
+				up version-history via working-copy working-copy-of))
+			{
+				$KW->{ $attr }->{ lc $word } = 'http://www.iana.org/assignments/relation/' . $word
+					unless defined $KW->{ $attr }->{ lc $word };
+			}
+		}
+	}
+
+	if ($terms =~ /\b(grddl)\b/i)
+	{
+		foreach my $attr (qw(rel rev))
+		{
+			foreach my $word (qw(transformation profileTransformation namespaceTransformation))
+			{
+				$KW->{ $attr }->{ lc $word } = 'http://www.w3.org/2003/g/data-view#' . $word
+					unless defined $KW->{ $attr }->{ lc $word };
+			}
+		}
+	}
+
+	if ($terms =~ /\b(xhtml-role|xhv)\b/i)
+	{
+		foreach my $word (qw(banner complementary contentinfo
+			definition main navigation note search))
+		{
+			$KW->{'role'}->{ lc $word } = 'http://www.w3.org/1999/xhtml/vocab#' . $word
+				unless defined $KW->{'role'}->{ lc $word };
+		}
+	}
+
+	if ($terms =~ /\b(aria-role|xhv)\b/i)
+	{
+		foreach my $word (qw(alert alertdialog application article
+			button checkbox columnheader combobox dialog directory
+			document grid gridcell group heading img link list listbox
+			listitem log marquee math menu menubar menuitem
+			menuitemcheckbox menuitemradio option presentation
+			progressbar radio radiogroup region row rowheader separator
+			slider spinbutton status tab tablist tabpanel textbox timer
+			toolbar tooltip tree treegrid treeitem))
+		{
+			$KW->{'role'}->{ lc $word } = 'http://www.w3.org/1999/xhtml/vocab#' . $word
+				unless defined $KW->{'role'}->{ lc $word };
+		}
+	}
+
+#	if ($terms =~ /\b(xfn)\b/i)
+#	{
+#		foreach my $attr (qw(rel rev))
+#		{
+#			foreach my $word (qw(contact acquaintance friend
+#				met co-worker colleague co-resident neighbor
+#				child parent sibling spouse kin muse crush date
+#				sweetheart me))
+#			{
+#				$KW->{ $attr }->{ lc $word } = 'http://vocab.sindice.com/xfn#' . $word . "-hyperlink"
+#					unless defined $KW->{ $attr }->{ lc $word };
+#			}
+#		}
+#	}
+	
+	$self->{'keywords'} = { 'insensitive' => $KW , 'sensitive' => $KW2 };
+}
+
 1;
 
 __END__
@@ -507,9 +558,7 @@ All you need to know about is the constructor:
 
 $host is the host language. Generally you would supply one of the
 following constants; the default is HOST_XHTML. Internet media types
-are accepted (e.g. 'text/html' or 'image/svg+xml'), but it's usually
-better to use a constant as some media types are shared (e.g. HTML4
-and HTML5 both use the same media type).
+are accepted (e.g. 'text/html' or 'image/svg+xml').
 
 =over
 
@@ -517,22 +566,18 @@ and HTML5 both use the same media type).
 
 =item * B<< RDF::RDFa::Parser::Config->HOST_DATARSS >>
 
-=item * B<< RDF::RDFa::Parser::Config->HOST_HTML32 >>
-
 =item * B<< RDF::RDFa::Parser::Config->HOST_HTML4 >>
 
 =item * B<< RDF::RDFa::Parser::Config->HOST_HTML5 >>
 
-=item * B<< RDF::RDFa::Parser::Config->HOST_OPENDOCUMENT_XML >> (Flat XML: "FODT", "FODS", etc)
+=item * B<< RDF::RDFa::Parser::Config->HOST_OPENDOCUMENT_XML >>
 
-=item * B<< RDF::RDFa::Parser::Config->HOST_OPENDOCUMENT_ZIP >> ("ODT", "ODS", etc)
+=item * B<< RDF::RDFa::Parser::Config->HOST_OPENDOCUMENT_ZIP >>
 
 =item * B<< RDF::RDFa::Parser::Config->HOST_SVG >>
 
 =item * B<< RDF::RDFa::Parser::Config->HOST_XHTML >>
 
-=item * B<< RDF::RDFa::Parser::Config->HOST_XHTML5 >>
-
 =item * B<< RDF::RDFa::Parser::Config->HOST_XML >>
 
 =back
@@ -552,10 +597,8 @@ following constants; the default is RDFA_LATEST.
 
 =back
 
-Version guessing: the root element is inspected for an attribute
-'version'. If this exists and matches /\bRDFa\s+(\d+\.\d+)\b/i
-then that is used as the version. Otherwise, the latest version
-is assumed.
+(RDFA_GUESS is currently just an alias for RDFA_LATEST. Version guessing
+is a planned feature.)
 
 %options is a hash of additional options to use which override the
 defaults. While many of these are useful, they probably also reduce
@@ -575,15 +618,11 @@ in brackets.
 
 =item * B<bookmark_start>, B<bookmark_end>, B<bookmark_name> - Elements to treat like OpenDocument's E<lt>text:bookmark-startE<gt> and E<lt>text:bookmark-endE<gt> element, and associated text:name attribute. Must set all three to use this feature. Use Clark Notation to specify namespaces. [all undef]
 
-=item * B<cite_attr> - support @cite [0]
-
-=item * B<datetime_attr> - support @datetime attribute and HTML5 <time> element. [0]
-
-=item * B<default_profiles> - THIS OPTION IS NO LONGER SUPPORTED!
+=item * B<default_profiles> - whitespace-separated list of profiles to load by default. [undef]
 
 =item * B<dom_parser> - parser to use to turn a markup string into a DOM. 'html', 'opendocument' (i.e. zipped XML) or 'xml'. ['xml']
 
-=item * B<embedded_rdfxml> - find plain RDF/XML chunks within document. 0=no, 1=handle, 2=skip. [0]
+=item * B<embedded_rdfxml> - find plain RDF/XML chunks within document. 0=no, 1=handle, 2=skip. [0]                      
 
 =item * B<full_uris> - support full URIs in CURIE-only attributes. [0, 1]
 
@@ -591,15 +630,11 @@ in brackets.
 
 =item * B<graph_attr> - attribute to use for named graphs. Use Clark Notation to specify a namespace. ['graph']
 
-=item * B<graph_type> - graph attribute behaviour ('id' or 'about'). ['about']
+=item * B<graph_type> - graph attribute behaviour ('id' or 'about'). ['id']
 
-=item * B<graph_default> - default graph name. [undef]
+=item * B<graph_default> - default graph name. ['_:RDFaDefaultGraph']
 
-=item * B<initial_context> - space-separated list of URIs, which must be keys in %RDF::RDFa::Parser::InitialContext::Known [?]
-
-=item * B<inlist_attr> - support @inlist. [0, 1]
-
-=item * B<longdesc_attr> - support @longdesc [0]
+=item * B<keyword_bundles> - space-separated list of bundles of keywords ('rdfa', 'html32', 'html4', 'html5', 'xhtml-role', 'aria-role', 'iana', 'xhv') ['rdfa']
 
 =item * B<lwp_ua> - an LWP::UserAgent to use for HTTP requests. [undef]
 
@@ -609,7 +644,9 @@ in brackets.
 
 =item * B<prefix_bare> - support CURIEs with no colon+suffix. [0]
 
-=item * B<prefix_default> - URI for default prefix (e.g. rel=":foo"). ['http://www.w3.org/1999/xhtml/vocab#']
+=item * B<prefix_default> - URI for default prefix (e.g. rel="foo"). [undef]
+
+=item * B<prefix_empty> - URI for empty prefix (e.g. rel=":foo"). ['http://www.w3.org/1999/xhtml/vocab#']
 
 =item * B<prefix_nocase> - DEPRECATED - shortcut for prefix_nocase_attr and prefix_nocase_xmlns.
 
@@ -617,41 +654,25 @@ in brackets.
 
 =item * B<prefix_nocase_xmlns> - ignore case-sensitivity of CURIE prefixes defined via xmlns. [0, 1]
 
-=item * B<profile_attr> - THIS OPTION IS NO LONGER SUPPORTED!
+=item * B<profiles> - support RDFa profiles. [0, 1]
 
-=item * B<profile_pi> - THIS OPTION IS NO LONGER SUPPORTED!
-
-=item * B<property_resources> - @property works for resources [0, 1]
+=item * B<profile_pi> - support DataRSS-style profile processing instruction. [0]
 
 =item * B<role_attr> - support for XHTML @role [0]
 
 =item * B<safe_anywhere> - allow Safe CURIEs in @rel/@rev/etc. [0, 1]
 
-=item * B<safe_optional> - allow Unsafe CURIEs in @about/@resource. [0, 1]
-
-=item * B<skolemize> - mint URIs instead of blank node identifiers. [0]
-
-=item * B<src_sets_object> - @src sets object URI (like @href) [0, 1]
-
 =item * B<tdb_service> - use thing-described-by.org to name some bnodes. [0]
 
-=item * B<typeof_resources> - allow @typeof to occasionally apply to objects rather than subjects. [0, 1]
-
 =item * B<user_agent> - a User-Agent header to use for HTTP requests. Ignored if lwp_ua is provided. [undef]
 
 =item * B<use_rtnlx> - use RDF::Trine::Node::Literal::XML. 0=no, 1=if available. [0]
 
-=item * B<value_attr> - support @value attribute (like @content) [0]
-
 =item * B<vocab_attr> - support @vocab from RDFa 1.1. [0, 1]
 
-=item * B<vocab_default> - default vocab URI (e.g. rel="foo"). [undef]
-
-=item * B<vocab_triple> - generate triple from @vocab. [0, 1]
-
 =item * B<xhtml_base> - process <base> element. 0=no, 1=yes, 2=use it for RDF/XML too. [1]                      
 
-=item * B<xhtml_elements> - process <head> and <body> specially. (Different special handling for XHTML+RDFa 1.0 and 1.1.) [1, 2]
+=item * B<xhtml_elements> - process <head> and <body> specially. [1]
 
 =item * B<xhtml_lang> - support @lang rather than just @xml:lang. [0]
 
@@ -661,15 +682,10 @@ in brackets.
 
 =item * B<xmllit_default> - Generate XMLLiterals enthusiastically. [1, 0]
 
-=item * B<xmllit_recurse> - Look for RDFa inside XMLLiterals. [0, 1]
-
 =item * B<xmlns_attr> - Support for 'xmlns:foo' to define CURIE prefixes. [1]
 
 =back
 
-An alternative constructor C<tagsoup> is provided with a useful set of
-options for dealing with content "from the wild".
-
 =head1 EXAMPLES
 
 The following full example parses RDFa 1.1 in an Atom document, also using
@@ -692,15 +708,6 @@ any RDF/XML chunks that are embedded in the document.
   use RDF::RDFa::Parser::Config qw(HOST_XHTML RDFA_11);
   $config = RDF::RDFa::Parser::Config->new(
     HOST_XHTML, RDFA_11, embedded_rdfxml=>1);
-  $parser = RDF::RDFa::Parser->new_from_url($url, $config);
-  $data   = $parser->graph;
-
-The following config is good for dealing with (X)HTML content from the
-wild:
-
-  $config = RDF::RDFa::Parser::Config->tagsoup;
-  $parser = RDF::RDFa::Parser->new_from_url($url, $config);
-  $data   = $parser->graph;
 
 =head1 SEE ALSO
 
@@ -710,15 +717,11 @@ L<RDF::RDFa::Parser>.
 
 Toby Inkster E<lt>tobyink@cpan.orgE<gt>.
 
-=head1 COPYRIGHT AND LICENCE
+=head1 COPYRIGHT
 
-Copyright 2008-2012 Toby Inkster
+Copyright 2008-2010 Toby Inkster
 
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
+This library is free software; you can redistribute it and/or modify it
+under the same terms as Perl itself.
 
-=head1 DISCLAIMER OF WARRANTIES
-
-THIS PACKAGE IS PROVIDED "AS IS" AND WITHOUT ANY EXPRESS OR IMPLIED
-WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED WARRANTIES OF
-MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+=cut
