@@ -1,10 +1,6 @@
 package RDF::RDFa::Parser::OpenDocumentObjectModel;
 
-BEGIN {
-	$RDF::RDFa::Parser::OpenDocumentObjectModel::AUTHORITY = 'cpan:TOBYINK';
-	$RDF::RDFa::Parser::OpenDocumentObjectModel::VERSION   = '1.096_04';	
-}
-
+our $VERSION = '1.091';
 our @Types = qw(
 	application/vnd.oasis.opendocument.chart
 	application/vnd.oasis.opendocument.database
@@ -157,51 +153,4 @@ sub parse_file
 	return $self->parse_string($content, $baseurl);
 }
 
-__PACKAGE__
-__END__
-
-=head1 NAME
-
-RDF::RDFa::Parser::OpenDocumentObjectModel - DOM representation of an OpenDocument Format 1.2 file
-
-=head1 DESCRIPTION
-
-You should hopefully not need to use this module to be able to use RDF::RDFa::Parser. It's
-used internally by the parser to deal with OpenDocument Format input.
-
-This class provides a C<new> constructor and C<parse_file>, C<parse_fh> and C<parse_string>
-methods offering rought compatibility with the parsing interface described in L<XML::LibXML::Parser>.
-
-It represents an OpenDocument Format 1.2 file (internally a ZIP file containing various XML,
-RDF/XML and other files) into a single L<XML::LibXML::Document> with a root element
-C<od:Document>. The root element has several child elements with tag names C<od:Data>
-and C<od:Meta> which each contain a single child corresponding to the root element of
-(respectively) an XML or RDF/XML file found inside the ZIP. (C<od:Data> and C<od:Meta> elements
-each have a C<file> attribute indicating which file.) This representation is necessarily
-different to the "Flat XML" format offered by OpenOffice - trust me.
-
-The "od" namespace URI is L<http://purl.org/NET/cpan-uri/dist/RDF-RDFa-Parser/opendocument-dom-wrapper>.
-
-=head1 SEE ALSO
-
-L<RDF::RDFa::Parser>.
-
-L<XML::LibXML::Parser>,
-L<HTML::HTML5::Parser>.
-
-=head1 AUTHOR
-
-Toby Inkster E<lt>tobyink@cpan.orgE<gt>.
-
-=head1 COPYRIGHT AND LICENCE
-
-Copyright 2008-2012 Toby Inkster
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
-=head1 DISCLAIMER OF WARRANTIES
-
-THIS PACKAGE IS PROVIDED "AS IS" AND WITHOUT ANY EXPRESS OR IMPLIED
-WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED WARRANTIES OF
-MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+1;
\ No newline at end of file
